@@ -14,11 +14,13 @@ def run(options):
             logging.error("%s must be set", r)
             sys.exit(1)
 
+    source = __name__.split(".")[-1]
+
     results = get_results(options)
     for result in results:
         logging.debug(result)
     logging.info("Fetched %d results", len(results))
-    return results
+    return results, source
 
 
 def get_results(options):
